==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/ResultRowValue.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ResultRowValue(
    key: __string,
    `type`: __string,
    value: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ResultRowValue = {
    import ResultRowValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ResultRowValue
      .builder()
      .key(__string.unwrap(key): java.lang.String)
      .`type`(__string.unwrap(`type`): java.lang.String)
      .value(__string.unwrap(value): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ResultRowValue.ReadOnly =
    zio.aws.pinpoint.model.ResultRowValue.wrap(buildAwsValue())
}
object ResultRowValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ResultRowValue =
      zio.aws.pinpoint.model.ResultRowValue(key, `type`, value)
    def key: __string
    def `type`: __string
    def value: __string
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
    def getType: ZIO[Any, Nothing, __string] = ZIO.succeed(`type`)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ) extends zio.aws.pinpoint.model.ResultRowValue.ReadOnly {
    override val key: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.key())
    override val `type`: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.`type`())
    override val value: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.value())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ): zio.aws.pinpoint.model.ResultRowValue.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/ResultRowValue.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ResultRowValue(
    key: __string,
    `type`: __string,
    value: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ResultRowValue = {
    import ResultRowValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ResultRowValue
      .builder()
      .key(key: java.lang.String)
      .`type`(`type`: java.lang.String)
      .value(value: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ResultRowValue.ReadOnly =
    zio.aws.pinpoint.model.ResultRowValue.wrap(buildAwsValue())
}
object ResultRowValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ResultRowValue =
      zio.aws.pinpoint.model.ResultRowValue(key, `type`, value)
    def key: __string
    def `type`: __string
    def value: __string
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
    def getType: ZIO[Any, Nothing, __string] = ZIO.succeed(`type`)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ) extends zio.aws.pinpoint.model.ResultRowValue.ReadOnly {
    override val key: __string = impl.key(): __string
    override val `type`: __string = impl.`type`(): __string
    override val value: __string = impl.value(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ResultRowValue
  ): zio.aws.pinpoint.model.ResultRowValue.ReadOnly = new Wrapper(impl)
}
